@@ -39,7 +39,7 @@ import           System.Time.Extra
 import           Test.Hls                        (TestConfig (testConfigCaps, testDirLocation, testDisableKick, testPluginDescriptor),
                                                   runSessionWithTestConfig,
                                                   waitForProgressBegin)
-import           Test.Hls.FileSystem             (directCradle, file, text)
+import           Test.Hls.FileSystem
 import           Test.Tasty
 import           Test.Tasty.HUnit
 
@@ -244,9 +244,7 @@ tests = testGroup "diagnostics"
       _ <- createDoc "ModuleB.hs" "haskell" contentB
       _ <- createDoc "ModuleB.hs-boot" "haskell" contentBboot
       expectDiagnostics [("ModuleB.hs", [(DiagnosticSeverity_Warning, (3,0), "Top-level binding", Just "GHC-38417")])]
-  , testWithDummyPlugin "bidirectional module dependency with hs-boot"
-        (mkIdeTestFs [directCradle ["ModuleA", "ModuleB"]])
-        $ do
+  , testWithDummyPluginEmpty "bidirectional module dependency with hs-boot" $ do
       let contentA = T.unlines
             [ "module ModuleA where"
             , "import {-# SOURCE #-} ModuleB"
@@ -343,19 +341,9 @@ tests = testGroup "diagnostics"
       expectDiagnostics
         [ ( "Main.hs"
           , [(DiagnosticSeverity_Error, (6, 9),
-                if ghcVersion >= GHC96 then
-                  "Variable not in scope: ThisList.map"
-                else if ghcVersion >= GHC94 then
-                  "Variable not in scope: map" -- See https://gitlab.haskell.org/ghc/ghc/-/issues/22130
-                else
-                  "Not in scope: \8216ThisList.map\8217", Just "GHC-88464")
+                  "Variable not in scope: ThisList.map", Just "GHC-88464")
             ,(DiagnosticSeverity_Error, (7, 9),
-                if ghcVersion >= GHC96 then
-                  "Variable not in scope: BaseList.x"
-                else if ghcVersion >= GHC94 then
-                  "Variable not in scope: x" -- See https://gitlab.haskell.org/ghc/ghc/-/issues/22130
-                else
-                  "Not in scope: \8216BaseList.x\8217", Just "GHC-88464")
+                  "Variable not in scope: BaseList.x", Just "GHC-88464")
             ]
           )
         ]
@@ -373,7 +361,7 @@ tests = testGroup "diagnostics"
       -- where appropriate. The warning should use an unqualified name 'Ord', not
       -- something like 'GHC.Classes.Ord'. The choice of redundant-constraints to
       -- test this is fairly arbitrary.
-          , [(DiagnosticSeverity_Warning, (2, if ghcVersion >= GHC94 then 7 else 0), "Redundant constraint: Ord a", Just "GHC-30606")
+          , [(DiagnosticSeverity_Warning, (2, 7), "Redundant constraint: Ord a", Just "GHC-30606")
             ]
           )
         ]
@@ -393,7 +381,7 @@ tests = testGroup "diagnostics"
               let (drive, suffix) = splitDrive pathB
               in filePathToUri (joinDrive (lower drive) suffix)
           liftIO $ createDirectoryIfMissing True (takeDirectory pathB)
-          liftIO $ writeFileUTF8 pathB $ T.unpack bContent
+          liftIO $ atomicFileWriteStringUTF8 pathB $ T.unpack bContent
           uriA <- getDocUri "A/A.hs"
           Just pathA <- pure $ uriToFilePath uriA
           uriA <- pure $
