@@ -11,18 +11,21 @@ module Ide.Plugin.Cabal.Diagnostics
 )
 where
 
-import qualified Data.Text                   as T
-import           Development.IDE             (FileDiagnostic,
-                                              ShowDiagnostic (ShowDiag))
-import           Distribution.Fields         (showPError, showPWarning)
-import qualified Distribution.Parsec         as Syntax
-import           Ide.PluginUtils             (extendNextLine)
-import           Language.LSP.Protocol.Types (Diagnostic (..),
-                                              DiagnosticSeverity (..),
-                                              NormalizedFilePath,
-                                              Position (Position),
-                                              Range (Range),
-                                              fromNormalizedFilePath)
+import           Control.Lens                      ((&), (.~))
+import qualified Data.Text                         as T
+import           Development.IDE                   (FileDiagnostic)
+import           Development.IDE.Types.Diagnostics (fdLspDiagnosticL,
+                                                    ideErrorWithSource)
+import           Distribution.Fields               (showPError, showPWarning)
+import qualified Distribution.Parsec               as Syntax
+import           Ide.PluginUtils                   (extendNextLine)
+import           Language.LSP.Protocol.Lens        (range)
+import           Language.LSP.Protocol.Types       (Diagnostic (..),
+                                                    DiagnosticSeverity (..),
+                                                    NormalizedFilePath,
+                                                    Position (Position),
+                                                    Range (Range),
+                                                    fromNormalizedFilePath)
 
 -- | Produce a diagnostic for a fatal Cabal parser error.
 fatalParseErrorDiagnostic :: NormalizedFilePath -> T.Text -> FileDiagnostic
@@ -63,8 +66,9 @@ positionFromCabalPosition :: Syntax.Position -> Position
 positionFromCabalPosition (Syntax.Position line column) = Position (fromIntegral line') (fromIntegral col')
   where
     -- LSP is zero-based, Cabal is one-based
-    line' = line-1
-    col' = column-1
+    -- Cabal can return line 0 for errors in the first line
+    line' = if line <= 0 then 0 else line-1
+    col' = if column <= 0 then 0 else column-1
 
 -- | Create a 'FileDiagnostic'
 mkDiag
@@ -79,15 +83,11 @@ mkDiag
   -> T.Text
   -- ^ The message displayed by the editor
   -> FileDiagnostic
-mkDiag file diagSource sev loc msg = (file, ShowDiag,)
-    Diagnostic
-    { _range    = loc
-    , _severity = Just sev
-    , _source   = Just diagSource
-    , _message  = msg
-    , _code     = Nothing
-    , _tags     = Nothing
-    , _relatedInformation = Nothing
-    , _codeDescription = Nothing
-    , _data_ = Nothing
-    }
+mkDiag file diagSource sev loc msg =
+  ideErrorWithSource
+    (Just diagSource)
+    (Just sev)
+    file
+    msg
+    Nothing
+    & fdLspDiagnosticL . range .~ loc
