@@ -1,8 +1,14 @@
 {-# OPTIONS_GHC -Wno-orphans #-}
 module Ide.Plugin.Cabal.Orphans where
 import           Control.DeepSeq
+import           Data.Aeson
+import qualified Data.Aeson                      as Aeson
+import qualified Data.Aeson.Types                as Aeson
+import qualified Data.Text                       as T
 import           Distribution.Fields.Field
-import           Distribution.Parsec.Position
+import           Distribution.PackageDescription (ComponentName)
+import           Distribution.Parsec
+import           Distribution.Pretty             (prettyShow)
 
 -- ----------------------------------------------------------------
 -- Cabal-syntax orphan instances we need sometimes
@@ -22,3 +28,12 @@ instance NFData (SectionArg Position) where
     rnf (SecArgName ann bs)  = rnf ann `seq` rnf bs
     rnf (SecArgStr ann bs)   = rnf ann `seq` rnf bs
     rnf (SecArgOther ann bs) = rnf ann `seq` rnf bs
+
+instance ToJSON ComponentName where
+    toJSON = Aeson.String . T.pack . prettyShow
+
+instance FromJSON ComponentName where
+    parseJSON = Aeson.withText "ComponentName" $ \t ->
+        case eitherParsec (T.unpack t) of
+            Left err -> Aeson.parseFail err
+            Right r  -> pure r
