@@ -83,30 +83,29 @@ cabalAddDependencyTests :: TestTree
 cabalAddDependencyTests =
   testGroup
     "Add dependency"
-    [ runHaskellTestCaseSession "Add to executable" ("cabal-add-testdata" </> "cabal-add-exe")
-        (generateAddDependencyTestSession "cabal-add-exe.cabal" ("src" </> "Main.hs") "split" [253])
-    , runHaskellTestCaseSession "Add to library" ("cabal-add-testdata" </> "cabal-add-lib")
-        (generateAddDependencyTestSession "cabal-add-lib.cabal" ("src" </> "MyLib.hs") "split" [348])
-    , runHaskellTestCaseSession "Add to testsuite" ("cabal-add-testdata" </> "cabal-add-tests")
-        (generateAddDependencyTestSession "cabal-add-tests.cabal" ("test" </> "Main.hs") "split" [478])
-    , runHaskellTestCaseSession "Add to testsuite with PackageImports" ("cabal-add-testdata" </> "cabal-add-tests")
-        (generateAddDependencyTestSession "cabal-add-tests.cabal" ("test" </> "MainPackageImports.hs") "split" [731])
-    , runHaskellTestCaseSession "Add to benchmark" ("cabal-add-testdata" </> "cabal-add-bench")
-        (generateAddDependencyTestSession "cabal-add-bench.cabal" ("bench" </> "Main.hs") "split" [403])
+    [ runHaskellTestCaseSession "Add to executable" ("cabal-add-testdata" </> "exe")
+        (generateAddDependencyTestSession "exe.cabal" ("src" </> "Main.hs") "split" [253])
+    , runHaskellTestCaseSession "Add to library" ("cabal-add-testdata" </> "lib")
+        (generateAddDependencyTestSession "lib.cabal" ("src" </> "MyLib.hs") "split" [348])
+    , runHaskellTestCaseSession "Add to testsuite" ("cabal-add-testdata" </> "tests")
+        (generateAddDependencyTestSession "tests.cabal" ("test" </> "Main.hs") "split" [478])
+    , runHaskellTestCaseSession "Add to testsuite with PackageImports" ("cabal-add-testdata" </> "tests")
+        (generateAddDependencyTestSession "tests.cabal" ("test" </> "MainPackageImports.hs") "split" [731])
+    , runHaskellTestCaseSession "Add to benchmark" ("cabal-add-testdata" </> "bench")
+        (generateAddDependencyTestSession "bench.cabal" ("bench" </> "Main.hs") "split" [403])
 
-    , runHaskellTestCaseSession "Add to executable, multiple targets" ("cabal-add-testdata" </> "cabal-add-multitarget")
-        (generateAddDependencyTestSession "cabal-add-multitarget.cabal" ("src" </> "Main.hs") "split" [269])
-    , runHaskellTestCaseSession "Add to library, multiple targets" ("cabal-add-testdata" </> "cabal-add-multitarget")
-        (generateAddDependencyTestSession "cabal-add-multitarget.cabal" ("lib" </> "MyLib.hs") "split" [413])
-    , runHaskellTestCaseSession "Add to internal library, multiple targets" ("cabal-add-testdata" </> "cabal-add-multitarget")
-        (generateAddDependencyTestSession "cabal-add-multitarget.cabal" ("lib" </> "InternalLib.hs") "split" [413])
-    , runHaskellTestCaseSession "Add to testsuite, multiple targets" ("cabal-add-testdata" </> "cabal-add-multitarget")
-        (generateAddDependencyTestSession "cabal-add-multitarget.cabal" ("test" </> "Main.hs") "split" [655])
-    , runHaskellTestCaseSession "Add to benchmark, multiple targets" ("cabal-add-testdata" </> "cabal-add-multitarget")
-        (generateAddDependencyTestSession "cabal-add-multitarget.cabal" ("bench" </> "Main.hs") "split" [776])
+    , runHaskellTestCaseSession "Add to executable, multiple targets" ("cabal-add-testdata" </> "multitarget")
+        (generateAddDependencyTestSession "multitarget.cabal" ("src" </> "Main.hs") "split" [269])
+    , runHaskellTestCaseSession "Add to library, multiple targets" ("cabal-add-testdata" </> "multitarget")
+        (generateAddDependencyTestSession "multitarget.cabal" ("lib" </> "MyLib.hs") "split" [413])
+    , runHaskellTestCaseSession "Add to internal library, multiple targets" ("cabal-add-testdata" </> "multitarget")
+        (generateAddDependencyTestSession "multitarget.cabal" ("lib" </> "InternalLib.hs") "split" [413])
+    , runHaskellTestCaseSession "Add to testsuite, multiple targets" ("cabal-add-testdata" </> "multitarget")
+        (generateAddDependencyTestSession "multitarget.cabal" ("test" </> "Main.hs") "split" [655])
+    , runHaskellTestCaseSession "Add to benchmark, multiple targets" ("cabal-add-testdata" </> "multitarget")
+        (generateAddDependencyTestSession "multitarget.cabal" ("bench" </> "Main.hs") "split" [776])
 
-
-    , runHaskellTestCaseSession "Guard against HPack" ("cabal-add-testdata" </> "cabal-add-packageYaml")
+    , runHaskellTestCaseSession "Guard against HPack" ("cabal-add-testdata" </> "packageYaml")
         (generatePackageYAMLTestSession ("src" </> "Main.hs"))
 
     , testHiddenPackageSuggestions "Check CabalAdd's parser, no version"
