@@ -12,6 +12,7 @@ import qualified Data.ByteString                                as ByteString
 import qualified Data.ByteString.Char8                          as BS8
 import           Data.Maybe                                     (mapMaybe)
 import qualified Data.Text                                      as T
+import           Development.IDE.Plugin.Completions.Types       (cursorPos)
 import qualified Development.IDE.Plugin.Completions.Types       as Ghcide
 import qualified Distribution.Fields                            as Syntax
 import           Distribution.PackageDescription                (GenericPackageDescription)
@@ -21,13 +22,18 @@ import           Ide.Plugin.Cabal.Completion.Completer.FilePath
 import           Ide.Plugin.Cabal.Completion.Completer.Module
 import           Ide.Plugin.Cabal.Completion.Completer.Paths
 import           Ide.Plugin.Cabal.Completion.Completer.Simple   (importCompleter)
-import           Ide.Plugin.Cabal.Completion.Completer.Types    (CompleterData (..))
+import           Ide.Plugin.Cabal.Completion.Completer.Types    (CompleterData (..),
+                                                                 Matcher (..))
 import           Ide.Plugin.Cabal.Completion.Completions
 import           Ide.Plugin.Cabal.Completion.Types              (CabalPrefixInfo (..),
                                                                  StanzaName)
 import qualified Language.LSP.Protocol.Lens                     as L
 import           System.FilePath
 import           Test.Hls
+import           Test.Hls.FileSystem                            (file,
+                                                                 mkVirtualFileTree,
+                                                                 text)
+import qualified Text.Fuzzy.Parallel                            as Fuzzy
 import           Utils
 
 completerTests :: TestTree
@@ -71,7 +77,20 @@ basicCompleterTests =
         let complTexts = getTextEditTexts compls
         liftIO $ assertBool "suggests f2" $ "f2.hs" `elem` complTexts
         liftIO $ assertBool "does not suggest" $ "Content.hs" `notElem` complTexts
-    ]
+    , parameterisedCursorTestM "extensions completion" libraryStanzaData
+        [ \_ actual -> assertBool "suggests FieldSelectors" $ "FieldSelectors" `elem` actual
+        , \_ actual -> assertBool "suggests OverloadedStrings" $ "OverloadedStrings" `elem` actual
+        , \_ actual -> assertBool "suggests something" $ not . null $ actual
+        , \_ actual -> assertBool "suggests NoLambdaCase" $ "NoLambdaCase" `elem` actual
+        , \_ actual -> assertBool "suggests RecordWildCards" $ "RecordWildCards" `elem` actual
+        ]
+        $ \fileContent posPrefInfo -> do
+            let vFileTree = mkVirtualFileTree "" $ [file "cabalFile.cabal" $ text fileContent]
+            runCabalSessionVft vFileTree $ do
+              doc <- openDoc "cabalFile.cabal" "cabal"
+              compls <- getCompletions doc (cursorPos posPrefInfo)
+              let complTexts = getTextEditTexts compls
+              pure complTexts]
     where
       getTextEditTexts :: [CompletionItem] -> [T.Text]
       getTextEditTexts compls = mapMaybe (^? L.textEdit . _Just . _L . L.newText) compls
@@ -270,7 +289,7 @@ filePathExposedModulesTests =
     callFilePathsForExposedModules :: [FilePath] -> IO [T.Text]
     callFilePathsForExposedModules srcDirs = do
       let prefInfo = simpleCabalPrefixInfoFromFp "" exposedTestDir
-      filePathsForExposedModules mempty srcDirs prefInfo
+      filePathsForExposedModules mempty srcDirs prefInfo $ Matcher $ Fuzzy.simpleFilter Fuzzy.defChunkSize Fuzzy.defMaxResults
 
 exposedModuleCompleterTests :: TestTree
 exposedModuleCompleterTests =
@@ -366,11 +385,19 @@ simpleCompleterData sName dir pref = do
         cabalContents <- ByteString.readFile $ testDataDir </> "exposed.cabal"
         pure $ parseGenericPackageDescriptionMaybe cabalContents,
       getCabalCommonSections = undefined,
-      stanzaName = sName
+      stanzaName = sName,
+      matcher = Matcher $ Fuzzy.simpleFilter Fuzzy.defChunkSize Fuzzy.defMaxResults
     }
 
 mkCompleterData :: CabalPrefixInfo -> CompleterData
-mkCompleterData prefInfo = CompleterData {getLatestGPD = undefined, getCabalCommonSections = undefined, cabalPrefixInfo = prefInfo, stanzaName = Nothing}
+mkCompleterData prefInfo =
+  CompleterData
+    { getLatestGPD = undefined,
+      getCabalCommonSections = undefined,
+      cabalPrefixInfo = prefInfo,
+      stanzaName = Nothing,
+      matcher = Matcher $ Fuzzy.simpleFilter Fuzzy.defChunkSize Fuzzy.defMaxResults
+    }
 
 exposedTestDir :: FilePath
 exposedTestDir = addTrailingPathSeparator $ testDataDir </> "src-modules"
@@ -391,40 +418,27 @@ extract item = case item ^. L.textEdit of
   Just (InL v) -> v ^. L.newText
   _            -> error ""
 
-importTestData :: T.Text
-importTestData = [__i|
-  cabal-version:      3.0
-  name:               hls-cabal-plugin
-  version:            0.1.0.0
-  synopsis:
-  homepage:
-  license:            MIT
-  license-file:       LICENSE
-  author:             Fendor
-  maintainer:         fendor@posteo.de
-  category:           Development
-  extra-source-files: CHANGELOG.md
+-- ------------------------------------------------------------------------
+-- Test Data
+-- ------------------------------------------------------------------------
 
-  common defaults
-    default-language: GHC2021
-    -- Should have been in GHC2021, an oversight
-    default-extensions: ExplicitNamespaces
-
-  common test-defaults
-    ghc-options: -threaded -rtsopts -with-rtsopts=-N
-
-  library
-      import:
-              ^
-      exposed-modules:  IDE.Plugin.Cabal
-      build-depends:    base ^>=4.14.3.0
-      hs-source-dirs:   src
-      default-language: Haskell2010
-
-  common notForLib
-    default-language: GHC2021
-
-  test-suite tests
-    import:
-            ^
+libraryStanzaData :: T.Text
+libraryStanzaData = [__i|
+    cabal-version:      3.0
+    name:               simple-cabal
+    common mylib
+      default-extensions: Field
+                               ^
+    library
+        default-extensions: Ov
+                              ^
+    test-suite mysuite
+        default-extensions:
+                            ^
+    executable myexe
+        default-extensions: NoLam
+                                 ^
+    benchmark mybench
+        other-extensions: RecordW
+                                 ^
 |]
