@@ -1,4 +1,4 @@
-module ErrorGivenPartialSignature where
+module TErrorGivenPartialSignature where
 
 partial :: Int -> Int
 partial x = init x
