@@ -11,6 +11,7 @@ import           Control.Lens                  (Prism', prism', view, (^.),
                                                 (^..), (^?))
 import           Control.Monad                 (void)
 import           Data.Foldable                 (find)
+import qualified Data.List                     as List
 import           Data.Maybe
 import qualified Data.Text                     as T
 import qualified Ide.Plugin.Class              as Class
@@ -109,9 +110,9 @@ codeLensTests = testGroup
             doc <- openDoc "CodeLensSimple.hs" "haskell"
             lens <- getAndResolveCodeLenses doc
             let titles = map (^. L.title) $ mapMaybe (^. L.command) lens
-            liftIO $ titles @?=
-                [ "(==) :: B -> B -> Bool"
-                , "(==) :: A -> A -> Bool"
+            liftIO $ List.sort titles @?=
+                [ "(==) :: A -> A -> Bool"
+                , "(==) :: B -> B -> Bool"
                 ]
     , testCase "No lens for TH" $ do
         runSessionWithServer def classPlugin testDataDir $ do
@@ -129,7 +130,7 @@ codeLensTests = testGroup
             liftIO $ length lens > 0 @?= True
         `catch` \(e :: SessionException) -> do
           liftIO $ assertFailure $ "classPluginTestError: "++ show e
-    , goldenCodeLens "Apply code lens" "CodeLensSimple" 1
+    , goldenCodeLens "Apply code lens" "CodeLensSimple" 0
     , goldenCodeLens "Apply code lens for local class" "LocalClassDefine" 0
     , goldenCodeLens "Apply code lens on the same line" "Inline" 0
     , goldenCodeLens "Don't insert pragma while existing" "CodeLensWithPragma" 0
@@ -155,7 +156,7 @@ goldenCodeLens :: TestName -> FilePath -> Int -> TestTree
 goldenCodeLens title path idx =
     goldenWithHaskellDoc def classPlugin title testDataDir path "expected" "hs" $ \doc -> do
         lens <- getAndResolveCodeLenses doc
-        executeCommand $ fromJust $ (lens !! idx) ^. L.command
+        executeCommand $ fromJust $ (List.sort lens !! idx) ^. L.command
         void $ skipManyTill anyMessage (message SMethod_WorkspaceApplyEdit)
 
 goldenWithClass ::TestName -> FilePath -> FilePath -> ([CodeAction] -> Session CodeAction) -> TestTree
