@@ -13,8 +13,8 @@ module Ide.Plugin.Eval (
 
 import           Development.IDE               (IdeState)
 import           Ide.Logger                    (Recorder, WithPriority)
-import qualified Ide.Plugin.Eval.CodeLens      as CL
 import           Ide.Plugin.Eval.Config
+import qualified Ide.Plugin.Eval.Handlers      as Handlers
 import           Ide.Plugin.Eval.Rules         (rules)
 import qualified Ide.Plugin.Eval.Types         as Eval
 import           Ide.Types                     (ConfigDescriptor (..),
@@ -27,9 +27,12 @@ import           Language.LSP.Protocol.Message
 -- |Plugin descriptor
 descriptor :: Recorder (WithPriority Eval.Log) -> PluginId -> PluginDescriptor IdeState
 descriptor recorder plId =
-    (defaultPluginDescriptor plId "Provies a code lens to evaluate expressions in doctest comments")
-        { pluginHandlers = mkPluginHandler SMethod_TextDocumentCodeLens (CL.codeLens recorder)
-        , pluginCommands = [CL.evalCommand recorder plId]
+    (defaultPluginDescriptor plId "Provides code action and lens to evaluate expressions in doctest comments")
+        { pluginHandlers = mconcat
+            [ mkPluginHandler SMethod_TextDocumentCodeAction (Handlers.codeAction recorder)
+            , mkPluginHandler SMethod_TextDocumentCodeLens (Handlers.codeLens recorder)
+            ]
+        , pluginCommands = [Handlers.evalCommand recorder plId]
         , pluginRules = rules recorder
         , pluginConfigDescriptor = defaultConfigDescriptor
                                    { configCustomConfig = mkCustomConfig properties
