@@ -87,6 +87,12 @@ import           Data.List.Extra                              (unsnoc)
 import           Development.IDE.Core.PluginUtils
 import           Development.IDE.Types.Shake                  (toKey)
 import           GHC.Types.SrcLoc                             (UnhelpfulSpanReason (UnhelpfulInteractive))
+#if MIN_VERSION_ghc(9,13,0)
+import           GHC.Types.Avail                              (DetOrdAvails (DefinitelyDeterministicAvails),
+                                                               sortAvails)
+import           GHC.Tc.Types                                 (tcg_exports)
+import           GHC.Types.Name.Set                           (nameSetElemsStable)
+#endif
 import           Ide.Logger                                   (Priority (..),
                                                                Recorder,
                                                                WithPriority,
@@ -262,11 +268,12 @@ initialiseSessionForEval needs_quickcheck st nfp = do
     -- it back to the iface for the current module.
     tm <- tmrTypechecked <$> use_ TypeCheck nfp
     let rdr_env = tcg_rdr_env tm
-    let linkable_hsc = loadModulesHome (map (addRdrEnv . linkableHomeMod) linkables) deps_hsc
         addRdrEnv hmi
           | iface <- hm_iface hmi
           , ms_mod ms == mi_module iface
-#if MIN_VERSION_ghc(9,11,0)
+#if MIN_VERSION_ghc(9,13,0)
+          = hmi { hm_iface = set_mi_top_env (IfaceTopEnv (sortAvails $ gresToAvailInfo $ globalRdrEnvElts $ globalRdrEnvLocal rdr_env) (mkIfaceImports $ tcg_import_decls tm)) iface}
+#elif MIN_VERSION_ghc(9,11,0)
           = hmi { hm_iface = set_mi_top_env (Just $ IfaceTopEnv (forceGlobalRdrEnv (globalRdrEnvLocal rdr_env)) (mkIfaceImports $ tcg_import_decls tm)) iface}
 #else
           = hmi { hm_iface = iface { mi_globals = Just $!
@@ -277,12 +284,20 @@ initialiseSessionForEval needs_quickcheck st nfp = do
                 }}
 #endif
           | otherwise = hmi
-
+#if MIN_VERSION_ghc(9,13,0)
+    linkable_hsc <- liftIO $ loadModulesHome (map (addRdrEnv . linkableHomeMod) linkables) deps_hsc
+#else
+    let linkable_hsc = loadModulesHome (map (addRdrEnv . linkableHomeMod) linkables) deps_hsc
+#endif
     return (ms, linkable_hsc)
   -- Bit awkward we need to use evalGhcEnv here but setContext requires to run
   -- in the Ghc monad
   env2 <- liftIO $ evalGhcEnv env1 $ do
+#if MIN_VERSION_ghc(9,13,0)
+            setContext [Compat.IIModule (ms_mod ms)]
+#else
             setContext [Compat.IIModule (moduleName (ms_mod ms))]
+#endif
             let df = flip xopt_set    LangExt.ExtendedDefaultRules
                    . flip xopt_unset  LangExt.MonomorphismRestriction
                    . flip gopt_set    Opt_ImplicitImportQualified
@@ -296,7 +311,14 @@ initialiseSessionForEval needs_quickcheck st nfp = do
             getSession
   return env2
 
-#if MIN_VERSION_ghc(9,11,0)
+#if MIN_VERSION_ghc(9,13,0)
+mkIfaceImports :: [ImportUserSpec] -> [IfaceImport]
+mkIfaceImports = map go
+  where
+    go (ImpUserSpec decl ImpUserAll) = IfaceImport decl ImpIfaceAll
+    go (ImpUserSpec decl (ImpUserExplicit avails parents)) = IfaceImport decl (ImpIfaceExplicit (DefinitelyDeterministicAvails avails) (nameSetElemsStable parents))
+    go (ImpUserSpec decl (ImpUserEverythingBut ns)) = IfaceImport decl (ImpIfaceEverythingBut (nameSetElemsStable ns))
+#elif MIN_VERSION_ghc(9,11,0)
 mkIfaceImports :: [ImportUserSpec] -> [IfaceImport]
 mkIfaceImports = map go
   where
@@ -463,10 +485,18 @@ evals recorder mark_exception fp df stmts = do
             dbg $ LogEvalFlags flags
             ndf <- getInteractiveDynFlags
             dbg $ LogEvalPreSetDynFlags ndf
+#if MIN_VERSION_ghc(9,13,0)
+            hsc_env <- getSession
+            eans <-
+                liftIO $ try @GhcException $
+                parseDynamicFlagsCmdLine (hsc_logger hsc_env) ndf
+                    (map (L $ UnhelpfulSpan unhelpfulReason) flags)
+#else
             eans <-
                 liftIO $ try @GhcException $
                 parseDynamicFlagsCmdLine ndf
                 (map (L $ UnhelpfulSpan unhelpfulReason) flags)
+#endif
             dbg $ LogEvalParsedFlags eans
             case eans of
                 Left err -> pure $ Just $ errorLines $ show err
