@@ -43,7 +43,11 @@ import           GHC                                    (AnnContext (..),
                                                          IsUnicodeSyntax (NormalSyntax),
                                                          NameAdornment (NameParens),
                                                          TrailingAnn (AddCommaAnn),
-                                                         emptyComments, reAnnL)
+                                                         emptyComments
+#if !MIN_VERSION_ghc(9,13,0)
+                                                        , reAnnL
+#endif
+                                                        )
 
 
 -- See Note [Guidelines For Using CPP In GHCIDE Import Statements]
@@ -66,6 +70,13 @@ import           GHC                                    (NoAnn (..))
 import           GHC                                    (EpAnnComments (..))
 #endif
 
+#if MIN_VERSION_ghc(9,13,0)
+import           GHC                                    (spanAsAnchor)
+
+reAnnL :: ann -> EpAnnComments -> Located e -> GenLocated (EpAnn ann) e
+reAnnL anns cs (L l a) = L (EpAnn (spanAsAnchor l) anns cs) a
+#endif
+
 ------------------------------------------------------------------------------
 
 -- | Construct a 'Rewrite', replacing the node at the given 'SrcSpan' with the
